==> blinka-displayio-pygamedisplay-0.0.2.tar.gz: blinka-displayio-pygamedisplay-0.0.2/setup.py <==
# SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
# SPDX-FileCopyrightText: Copyright (c) 2020 Tim C for foamyguy
#
# SPDX-License-Identifier: MIT

"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="blinka-displayio-pygamedisplay",
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    description="Use CircuitPython displayio code on PC and Raspberry Pi outputting to a PyGame window instead of a phyisical display.",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # The project's main homepage.
    url="https://github.com/adafruit/Adafruit_CircuitPython_Blinka_Displayio_PyGameDisplay",
    # Author details
    author="Tim C",
    author_email="foamyguy@gmail.com",
    install_requires=["pygame", "adafruit-blinka-displayio"],
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    # What does your project relate to?
    keywords="adafruit blinka circuitpython micropython blinka_displayio_pygamedisplay "
    "displayio hdmi pc window pygame",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # TODO: IF LIBRARY FILES ARE A PACKAGE FOLDER,
    #       CHANGE `py_modules=['...']` TO `packages=['...']`
    py_modules=["blinka_displayio_pygamedisplay"],
)

==> blinka-displayio-pygamedisplay-0.0.5.tar.gz: blinka-displayio-pygamedisplay-0.0.5/setup.py <==
# SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
# SPDX-FileCopyrightText: Copyright (c) 2020 Tim C for foamyguy
#
# SPDX-License-Identifier: MIT

"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="blinka-displayio-pygamedisplay",
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    description="Use CircuitPython displayio code on PC and Raspberry Pi outputting to a PyGame window instead of a phyisical display.",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # The project's main homepage.
    url="https://github.com/foamyguy/Blinka_Displayio_PyGameDisplay",
    # Author details
    author="Tim C",
    author_email="foamyguy@gmail.com",
    install_requires=["pygame", "adafruit-blinka-displayio"],
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    # What does your project relate to?
    keywords="adafruit blinka circuitpython micropython blinka_displayio_pygamedisplay "
    "displayio hdmi pc window pygame",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # TODO: IF LIBRARY FILES ARE A PACKAGE FOLDER,
    #       CHANGE `py_modules=['...']` TO `packages=['...']`
    py_modules=["blinka_displayio_pygamedisplay"],
)
